<?php

namespace Netzmacher\QuickShop\Utility\TCA;

use Netzmacher\QuickShop\Utility\Userfunc\TYPO3v;

if( !defined( 'TYPO3_MODE' ) )
{
  die( 'Access denied.' );
}

/* * *************************************************************
 *  Copyright notice
 *
 *  (c) 2017 -  Dirk Wildt <http://wildt.at.die-netzmacher.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 * ************************************************************* */

/**
 * Class provides methods for the extension manager.
 *
 * @author      Dirk Wildt <http://wildt.at.die-netzmacher.de>
 * @package     TYPO3
 * @subpackage  quick_shop
 * @version     7.0.2
 * @since       7.0.2
 */
class Icons
{

  private $pathDefault = 'EXT:quick_shop/ext_icon';
  private $pathNotype = 'EXT:quick_shop/Resources/Public/Images/Icons/ExtIcon/notype';
  private $pathPage = 'EXT:quick_shop/Resources/Public/Images/Icons/ExtIcon/page';
  private $pathRecord = 'EXT:quick_shop/Resources/Public/Images/Icons/ExtIcon/record';
  private $pathUrl = 'EXT:quick_shop/Resources/Public/Images/Icons/ExtIcon/url';

  /**
   * Get icon array with classes and paths
   *
   * @return      void
   * @version     7.0.2
   * @since       7.0.2
   */
  private function getClassWiIcons( $ext = 'svg' )
  {
    return array(
        'ext-quickshop-products' => $this->pathDefault . '.' . $ext,
        'ext-quickshop-notype' => $this->pathNotype . '.' . $ext,
        'ext-quickshop-page' => $this->pathPage . '.' . $ext,
        'ext-quickshop-record' => $this->pathRecord . '.' . $ext,
        'ext-quickshop-url' => $this->pathUrl . '.' . $ext,
    );
  }

  /**
   * Get icon array 
   *
   * @return      array
   * @version     7.0.2
   * @since       7.0.2
   */
  public function typeIconClasses()
  {
    switch( TRUE )
    {
      case( TYPO3v::get() < 7006000 ):
        return $this->typeIcons6x();
      case( TYPO3v::get() >= 7006000 ):
      default:
        return $this->typeIconClasses7x();
    }
  }

  /**
   * Get icon array 
   *
   * @return      array
   * @version     7.0.2
   * @since       7.0.2
   */
  private function typeIcons6x( $ext = 'svg' )
  {
    return array(
        'typeicons' => array(
            'default' => $this->pathDefault . '.' . $ext,
            'notype' => $this->pathNotype . '.' . $ext,
            'page' => $this->pathPage . '.' . $ext,
            'record' => $this->pathRecord . '.' . $ext,
            'url' => $this->pathUrl . '.' . $ext,
        ),
    );
  }

  /**
   * Get icon array 
   *
   * @return      array
   * @version     7.0.2
   * @since       7.0.2
   */
  private function typeIconClasses7x()
  {
    return array(
        'typeicon_classes' => array(
            'default' => 'ext-quickshop-products',
            'notype' => 'ext-quickshop-notype',
            'page' => 'ext-quickshop-page',
            'record' => 'ext-quickshop-record',
            'url' => 'ext-quickshop-url',
            'XXdefault' => 'mimetypes-x-content-text',
        ),
    );
  }

  /**
   * Get icon array with classes and paths
   *
   * @return      void
   * @version     7.0.2
   * @since       7.0.2
   */
  private function getPath( $icon )
  {
    switch( TRUE )
    {
      case( TYPO3v::get() < 7006000 ):
        $ext = 'gif';
        break;
      case( TYPO3v::get() >= 7006000 ):
      default:
        $ext = 'svg';
        break;
    }

    switch( $icon )
    {
      case('notype'):
        return $this->pathNotype . '.' . $ext;
      case('page'):
        return $this->pathPage . '.' . $ext;
      case('record'):
        return $this->pathRecord . '.' . $ext;
      case('url'):
        return $this->pathUrl . '.' . $ext;
      case('default'):
      default:
        return $this->pathDefault . '.' . $ext;
    }
  }

  /**
   * Get path of the icon default
   *
   * @return      string path
   * @version     7.0.2
   * @since       7.0.2
   */
  public function iconDefault()
  {
    return $this->getPath( 'default' );
  }

  /**
   * Get path of the icon notype
   *
   * @return      string path
   * @version     7.0.2
   * @since       7.0.2
   */
  public function iconNotype()
  {
    return $this->getPath( 'notype' );
  }

  /**
   * Get path of the icon page
   *
   * @return      string path
   * @version     7.0.2
   * @since       7.0.2
   */
  public function iconPage()
  {
    return $this->getPath( 'page' );
  }

  /**
   * Get path of the icon record
   *
   * @return      string path
   * @version     7.0.2
   * @since       7.0.2
   */
  public function iconRecord()
  {
    return $this->getPath( 'record' );
  }

  /**
   * Get path of the icon url
   *
   * @return      string path
   * @version     7.0.2
   * @since       7.0.2
   */
  public function iconUrl()
  {
    return $this->getPath( 'url' );
  }

  /**
   * Register Icons
   *
   * @return      void
   * @version     7.0.2
   * @since       7.0.2
   */
  public function registerIcons( $ext = 'svg' )
  {
    if( TYPO3v::get() < 7006000 )
    {
      return;
    }

    $iconRegistry = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance( \TYPO3\CMS\Core\Imaging\IconRegistry::class );

    foreach( $this->getClassWiIcons( $ext ) as $class => $source )
    {
      $iconRegistry->registerIcon(
              $class
              , \TYPO3\CMS\Core\Imaging\IconProvider\SvgIconProvider::class
              , [ 'source' => $source ]
      );
    }
  }

}
